@@ -22,8 +22,11 @@ from speechbrain.processing.speech_augmentation import (
     AddNoise,
     AddReverb,
 )
+from speechbrain.utils.torch_audio_backend import get_torchaudio_backend
+
+torchaudio_backend = get_torchaudio_backend()
+torchaudio.set_audio_backend(torchaudio_backend)
 
-torchaudio.set_audio_backend("sox_io")
 OPENRIR_URL = "http://www.openslr.org/resources/28/rirs_noises.zip"
 
 
@@ -111,8 +114,7 @@ class SpecAugment(torch.nn.Module):
         return x
 
     def time_warp(self, x):
-        """Time warping with torch.nn.functional.interpolate
-        """
+        """Time warping with torch.nn.functional.interpolate"""
         original_size = x.shape
         window = self.time_warp_window
 
